<?php
/**
 * iApp Theme Customizer
 *
 * @package iapp
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function iapp_customize_register( $wp_customize ) {
	
	
	$iapp_transitions = array(
				'pt-page-moveToRight$pt-page-moveFromLeft' 							=> __('Move To Right - Move From Left', 'iapp'),
				'pt-page-moveToBottom$pt-page-moveFromTop' 							=> __('Move To Bottom - Move From Top', 'iapp'),
				'pt-page-rotateFoldRight$pt-page-moveFromLeftFade' 					=> __('Rotate Fold Right - Move From Left', 'iapp'),
				'pt-page-rotateCubeLeftOut pt-page-ontop$pt-page-rotateCubeLeftIn'	=> __('Rotate Cube Left Out - Rotate Cube Left In', 'iapp'),
    );
	
	
    //  =============================================================
    //  = 					 Homepage Options						=
    //  =============================================================
	
	$wp_customize->add_panel( 'iapp_homepage_apps_options', array(
	    'priority' 			=> 1,
	    'capability' 		=> 'edit_theme_options',
	    'theme_supports' 	=> '',
	    'title' 			=> __( 'Homepage Apps Options', 'iapp' ),
	    'description' 		=> __( 'To Have All iApp Theme Features Upgrade to iApp Pro: <a href="http://theme-art.com/iapp/" target="_blank" class="get-pro">iApp Pro Demo</a>', 'iapp' ),
	) );

	
	// ---------------------- App Options 1 -------------------
	
	
    $wp_customize->add_section('iapp_options_1', array(
        'title'    			=> __('App Options 1', 'iapp'),
        'priority' 			=> 120,
		'panel'				=> 'iapp_homepage_apps_options'
    ));

    $wp_customize->add_setting('iapp_enable_1', array(
		'default'			=> 1,
		'sanitize_callback' => 'sanitize_text_field',
        'capability' 		=> 'edit_theme_options',
        'type'       		=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_enable_1', array(
		'label'    			=> __('Enable This App', 'iapp'),
        'settings' 			=> 'iapp_enable_1',
        'section'  			=> 'iapp_options_1',
        'type'     			=> 'checkbox',
    ));

    $wp_customize->add_setting('iapp_name_1', array(
        'default'        	=> __('Portfolio', 'iapp'),
		'sanitize_callback' => 'sanitize_title',
        'capability'     	=> 'edit_theme_options',
        'type' 			 	=> 'theme_mod', 
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_name_1', array(
        'label'      		=> __('App Name', 'iapp'),
        'section'    		=> 'iapp_options_1',
        'settings'   		=> 'iapp_name_1',
    ));

    $wp_customize->add_setting('iapp_icon_1', array(
        'default'           => get_template_directory_uri().'/images/app/app-portfolio.png',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_icon_1', array(
        'label'    			=> __('App Icon', 'iapp'),
        'section'  			=> 'iapp_options_1',
        'settings' 			=> 'iapp_icon_1',
    )));

    $wp_customize->add_setting('iapp_color_1', array(
        'default'           => '#61CAFF',
        'sanitize_callback' => 'sanitize_hex_color',
        'capability'        => 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'iapp_color_1', array(
        'label'    			=> __('App Color', 'iapp'),
        'section'  			=> 'iapp_options_1',
        'settings' 			=> 'iapp_color_1',
    )));
	
    $wp_customize->add_setting('iapp_css_1', array(
		'sanitize_callback' => 'wp_filter_nohtml_kses',
		'sanitize_js_callback' => 'wp_filter_nohtml_kses',
		'default'        	=> 'background: linear-gradient(215deg, rgba(255,0,255,1) , rgba(0,255,255,1));',
        'capability'     	=> 'edit_theme_options',
        'type' 				=> 'theme_mod', 
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_css_1', array(
        'label'     		=> __('App Custom CSS Style', 'iapp'),
        'section'    		=> 'iapp_options_1',
        'settings'   		=> 'iapp_css_1',
		'type'				=> 'textarea',
    ));

    $wp_customize->add_setting('iapp_page_1', array(
		'sanitize_callback' => 'sanitize_text_field',
        'capability'     	=> 'edit_theme_options',
        'type'           	=> 'theme_mod',
    ));

    $wp_customize->add_control('iapp_page_1', array(
        'label'      		=> __('Select Page', 'iapp'),
        'section'    		=> 'iapp_options_1',
        'type'    			=> 'dropdown-pages',
        'settings'  		=> 'iapp_page_1',
    ));

     $wp_customize->add_setting('iapp_transition_1', array(
        'default'        	=> 'pt-page-rotateCubeLeftOut pt-page-ontop$pt-page-rotateCubeLeftIn',
		'sanitize_callback' => 'sanitize_text_field',
        'capability'     	=> 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));
    $wp_customize->add_control( 'iapp_transition_1', array(
        'settings' 			=> 'iapp_transition_1',
        'label'   			=> __('Select Page Transition', 'iapp'),
		'description' 		=> __('Get 40+ Page Transitions: <a href="http://theme-art.com/iapp/" target="_blank" class="get-pro">iApp Pro</a>', 'iapp'),
        'section'	 		=> 'iapp_options_1',
        'type'    			=> 'select',
        'choices'    		=> $iapp_transitions,
    ));

    $wp_customize->add_setting('iapp_pagebgimage_1', array(
        'default'           => get_template_directory_uri().'/images/background.jpg',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_pagebgimage_1', array(
        'label'    			=> __('Page Background Image', 'iapp'),
        'section'  			=> 'iapp_options_1',
        'settings' 			=> 'iapp_pagebgimage_1',
    )));

    $wp_customize->add_setting('iapp_pagebgcolor_1', array(
        'default'           => '#0FA2CB',
        'sanitize_callback' => 'sanitize_hex_color',
        'capability'        => 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'iapp_pagebgcolor_1', array(
        'label'    			=> __('Page Background Color', 'iapp'),
        'section'  			=> 'iapp_options_1',
        'settings' 			=> 'iapp_pagebgcolor_1',
    )));

	// ---------------------- App Options 2 -------------------
	
	
    $wp_customize->add_section('iapp_options_2', array(
        'title'    			=> __('App Options 2', 'iapp'),
        'priority' 			=> 121,
		'panel'				=> 'iapp_homepage_apps_options'
    ));

    $wp_customize->add_setting('iapp_enable_2', array(
		'default'			=> 1,
		'sanitize_callback' => 'sanitize_text_field',
        'capability' 		=> 'edit_theme_options',
        'type'       		=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_enable_2', array(
		'label'    			=> __('Enable This App', 'iapp'),
        'settings' 			=> 'iapp_enable_2',
        'section'  			=> 'iapp_options_2',
        'type'     			=> 'checkbox',
    ));

    $wp_customize->add_setting('iapp_name_2', array(
        'default'        	=> __('About', 'iapp'),
		'sanitize_callback' => 'sanitize_title',
        'capability'     	=> 'edit_theme_options',
        'type' 			 	=> 'theme_mod', 
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_name_2', array(
        'label'      		=> __('App Name', 'iapp'),
        'section'    		=> 'iapp_options_2',
        'settings'   		=> 'iapp_name_2',
    ));

    $wp_customize->add_setting('iapp_icon_2', array(
        'default'           => get_template_directory_uri().'/images/app/app-about.png',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_icon_2', array(
        'label'    			=> __('App Icon', 'iapp'),
        'section'  			=> 'iapp_options_2',
        'settings' 			=> 'iapp_icon_2',
    )));

    $wp_customize->add_setting('iapp_color_2', array(
        'default'           => '#0390B7',
        'sanitize_callback' => 'sanitize_hex_color',
        'capability'        => 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'iapp_color_2', array(
        'label'    			=> __('App Color', 'iapp'),
        'section'  			=> 'iapp_options_2',
        'settings' 			=> 'iapp_color_2',
    )));
	
    $wp_customize->add_setting('iapp_css_2', array(
		'sanitize_callback' => 'wp_filter_nohtml_kses',
		'sanitize_js_callback' => 'wp_filter_nohtml_kses',
		'default'        	=> 'background: linear-gradient(45deg, rgba(0,59,59,1) , rgba(5,193,255,1) , rgba(0,59,59,1) );',
        'capability'     	=> 'edit_theme_options',
        'type' 				=> 'theme_mod', 
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_css_2', array(
        'label'     		=> __('App Custom CSS Style', 'iapp'),
        'section'    		=> 'iapp_options_2',
        'settings'   		=> 'iapp_css_2',
		'type'				=> 'textarea',
    ));

    $wp_customize->add_setting('iapp_page_2', array(
		'sanitize_callback' => 'sanitize_text_field',
        'capability'     	=> 'edit_theme_options',
        'type'           	=> 'theme_mod',
    ));

    $wp_customize->add_control('iapp_page_2', array(
        'label'      		=> __('Select Page', 'iapp'),
        'section'    		=> 'iapp_options_2',
        'type'    			=> 'dropdown-pages',
        'settings'  		=> 'iapp_page_2',
    ));

     $wp_customize->add_setting('iapp_transition_2', array(
        'default'        	=> 'pt-page-rotateFoldRight$pt-page-moveFromLeftFade',
		'sanitize_callback' => 'sanitize_text_field',
        'capability'     	=> 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));
    $wp_customize->add_control( 'iapp_transition_2', array(
        'settings' 			=> 'iapp_transition_2',
        'label'   			=> __('Select Page Transition', 'iapp'),
		'description' 		=> __('Get 40+ Page Transitions: <a href="http://theme-art.com/iapp/" target="_blank" class="get-pro">iApp Pro</a>', 'iapp'),
        'section'	 		=> 'iapp_options_2',
        'type'    			=> 'select',
        'choices'    		=> $iapp_transitions,
    ));

    $wp_customize->add_setting('iapp_pagebgimage_2', array(
        'default'           => get_template_directory_uri().'/images/background.jpg',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_pagebgimage_2', array(
        'label'    			=> __('Page Background Image', 'iapp'),
        'section'  			=> 'iapp_options_2',
        'settings' 			=> 'iapp_pagebgimage_2',
    )));

    $wp_customize->add_setting('iapp_pagebgcolor_2', array(
        'default'           => '#0FA2CB',
        'sanitize_callback' => 'sanitize_hex_color',
        'capability'        => 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'iapp_pagebgcolor_2', array(
        'label'    			=> __('Page Background Color', 'iapp'),
        'section'  			=> 'iapp_options_2',
        'settings' 			=> 'iapp_pagebgcolor_2',
    )));
	
	
	// ---------------------- App Options 3 -------------------
	
	
    $wp_customize->add_section('iapp_options_3', array(
        'title'    			=> __('App Options 3', 'iapp'),
        'priority' 			=> 122,
		'panel'				=> 'iapp_homepage_apps_options'
    ));

    $wp_customize->add_setting('iapp_enable_3', array(
		'default'			=> 1,
		'sanitize_callback' => 'sanitize_text_field',
        'capability' 		=> 'edit_theme_options',
        'type'       		=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_enable_3', array(
		'label'    			=> __('Enable This App', 'iapp'),
        'settings' 			=> 'iapp_enable_3',
        'section'  			=> 'iapp_options_3',
        'type'     			=> 'checkbox',
    ));

    $wp_customize->add_setting('iapp_name_3', array(
        'default'        	=> __('Team', 'iapp'),
		'sanitize_callback' => 'sanitize_title',
        'capability'     	=> 'edit_theme_options',
        'type' 			 	=> 'theme_mod', 
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_name_3', array(
        'label'      		=> __('App Name', 'iapp'),
        'section'    		=> 'iapp_options_3',
        'settings'   		=> 'iapp_name_3',
    ));

    $wp_customize->add_setting('iapp_icon_3', array(
        'default'           => get_template_directory_uri().'/images/app/app-team.png',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_icon_3', array(
        'label'    			=> __('App Icon', 'iapp'),
        'section'  			=> 'iapp_options_3',
        'settings' 			=> 'iapp_icon_3',
    )));

    $wp_customize->add_setting('iapp_color_3', array(
        'default'           => '#00FF2D',
        'sanitize_callback' => 'sanitize_hex_color',
        'capability'        => 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'iapp_color_3', array(
        'label'    			=> __('App Color', 'iapp'),
        'section'  			=> 'iapp_options_3',
        'settings' 			=> 'iapp_color_3',
    )));
	
    $wp_customize->add_setting('iapp_css_3', array(
		'sanitize_callback' => 'wp_filter_nohtml_kses',
		'sanitize_js_callback' => 'wp_filter_nohtml_kses',
		'default'        	=> 'background: linear-gradient(45deg, rgba(0,255,0,1), rgba(0,255,255,1));',
        'capability'     	=> 'edit_theme_options',
        'type' 				=> 'theme_mod', 
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_css_3', array(
        'label'     		=> __('App Custom CSS Style', 'iapp'),
        'section'    		=> 'iapp_options_3',
        'settings'   		=> 'iapp_css_3',
		'type'				=> 'textarea',
    ));

    $wp_customize->add_setting('iapp_page_3', array(
		'sanitize_callback' => 'sanitize_text_field',
        'capability'     	=> 'edit_theme_options',
        'type'           	=> 'theme_mod',
    ));

    $wp_customize->add_control('iapp_page_3', array(
        'label'      		=> __('Select Page', 'iapp'),
        'section'    		=> 'iapp_options_3',
        'type'    			=> 'dropdown-pages',
        'settings'  		=> 'iapp_page_3',
    ));

     $wp_customize->add_setting('iapp_transition_3', array(
        'default'        	=> 'pt-page-moveToBottom$pt-page-moveFromTop',
		'sanitize_callback' => 'sanitize_text_field',
        'capability'     	=> 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));
    $wp_customize->add_control( 'iapp_transition_3', array(
        'settings' 			=> 'iapp_transition_3',
        'label'   			=> __('Select Page Transition', 'iapp'),
		'description' 		=> __('Get 40+ Page Transitions: <a href="http://theme-art.com/iapp/" target="_blank" class="get-pro">iApp Pro</a>', 'iapp'),
        'section'	 		=> 'iapp_options_3',
        'type'    			=> 'select',
        'choices'    		=> $iapp_transitions,
    ));

    $wp_customize->add_setting('iapp_pagebgimage_3', array(
        'default'           => get_template_directory_uri().'/images/background.jpg',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_pagebgimage_3', array(
        'label'    			=> __('Page Background Image', 'iapp'),
        'section'  			=> 'iapp_options_3',
        'settings' 			=> 'iapp_pagebgimage_3',
    )));

    $wp_customize->add_setting('iapp_pagebgcolor_3', array(
        'default'           => '#0FA2CB',
        'sanitize_callback' => 'sanitize_hex_color',
        'capability'        => 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'iapp_pagebgcolor_3', array(
        'label'    			=> __('Page Background Color', 'iapp'),
        'section'  			=> 'iapp_options_3',
        'settings' 			=> 'iapp_pagebgcolor_3',
    )));
	

	// ---------------------- App Options 4 -------------------
	
	
    $wp_customize->add_section('iapp_options_4', array(
        'title'    			=> __('App Options 4', 'iapp'),
        'priority' 			=> 123,
		'panel'				=> 'iapp_homepage_apps_options'
    ));

    $wp_customize->add_setting('iapp_enable_4', array(
		'default'			=> 1,
		'sanitize_callback' => 'sanitize_text_field',
        'capability' 		=> 'edit_theme_options',
        'type'       		=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_enable_4', array(
		'label'    			=> __('Enable This App', 'iapp'),
        'settings' 			=> 'iapp_enable_4',
        'section'  			=> 'iapp_options_4',
        'type'     			=> 'checkbox',
    ));

    $wp_customize->add_setting('iapp_name_4', array(
        'default'        	=> __('Blog', 'iapp'),
		'sanitize_callback' => 'sanitize_title',
        'capability'     	=> 'edit_theme_options',
        'type' 			 	=> 'theme_mod', 
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_name_4', array(
        'label'      		=> __('App Name', 'iapp'),
        'section'    		=> 'iapp_options_4',
        'settings'   		=> 'iapp_name_4',
    ));

    $wp_customize->add_setting('iapp_icon_4', array(
        'default'           => get_template_directory_uri().'/images/app/app-blog.png',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_icon_4', array(
        'label'    			=> __('App Icon', 'iapp'),
        'section'  			=> 'iapp_options_4',
        'settings' 			=> 'iapp_icon_4',
    )));

    $wp_customize->add_setting('iapp_color_4', array(
        'default'           => '#3470C9',
        'sanitize_callback' => 'sanitize_hex_color',
        'capability'        => 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'iapp_color_4', array(
        'label'    			=> __('App Color', 'iapp'),
        'section'  			=> 'iapp_options_4',
        'settings' 			=> 'iapp_color_4',
    )));
	
    $wp_customize->add_setting('iapp_css_4', array(
		'sanitize_callback' => 'wp_filter_nohtml_kses',
		'sanitize_js_callback' => 'wp_filter_nohtml_kses',
		'default'        	=> 'background: linear-gradient(215deg, rgba(255,102,102,1) , rgba(0,255,255,1) );',
        'capability'     	=> 'edit_theme_options',
        'type' 				=> 'theme_mod', 
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_css_4', array(
        'label'     		=> __('App Custom CSS Style', 'iapp'),
        'section'    		=> 'iapp_options_4',
        'settings'   		=> 'iapp_css_4',
		'type'				=> 'textarea',
    ));

    $wp_customize->add_setting('iapp_page_4', array(
		'sanitize_callback' => 'sanitize_text_field',
        'capability'     	=> 'edit_theme_options',
        'type'           	=> 'theme_mod',
    ));

    $wp_customize->add_control('iapp_page_4', array(
        'label'      		=> __('Select Page', 'iapp'),
        'section'    		=> 'iapp_options_4',
        'type'    			=> 'dropdown-pages',
        'settings'  		=> 'iapp_page_4',
    ));

     $wp_customize->add_setting('iapp_transition_4', array(
        'default'        	=> 'pt-page-moveToRight$pt-page-moveFromLeft',
		'sanitize_callback' => 'sanitize_text_field',
        'capability'     	=> 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));
    $wp_customize->add_control( 'iapp_transition_4', array(
        'settings' 			=> 'iapp_transition_4',
        'label'   			=> __('Select Page Transition', 'iapp'),
		'description' 		=> __('Get 40+ Page Transitions: <a href="http://theme-art.com/iapp/" target="_blank" class="get-pro">iApp Pro</a>', 'iapp'),
        'section'	 		=> 'iapp_options_4',
        'type'    			=> 'select',
        'choices'    		=> $iapp_transitions,
    ));

    $wp_customize->add_setting('iapp_pagebgimage_4', array(
        'default'           => get_template_directory_uri().'/images/background.jpg',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_pagebgimage_4', array(
        'label'    			=> __('Page Background Image', 'iapp'),
        'section'  			=> 'iapp_options_4',
        'settings' 			=> 'iapp_pagebgimage_4',
    )));

    $wp_customize->add_setting('iapp_pagebgcolor_4', array(
        'default'           => '#0FA2CB',
        'sanitize_callback' => 'sanitize_hex_color',
        'capability'        => 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'iapp_pagebgcolor_4', array(
        'label'    			=> __('Page Background Color', 'iapp'),
        'section'  			=> 'iapp_options_4',
        'settings' 			=> 'iapp_pagebgcolor_4',
    )));
	
	
	// ---------------------- More Apps -------------------
	
	
    $wp_customize->add_section('iapp_more', array(
        'title'    			=> __('More Apps', 'iapp'),
        'priority' 			=> 124,
		'panel'				=> 'iapp_homepage_apps_options'
    ));

    $wp_customize->add_setting('iapp_pro', array(
        'default'           => get_template_directory_uri().'/images/iapp-pro.png',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',

    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_pro', array(
        'label'    			=> __('Need More Apps', 'iapp'),
		'description'		=> __('Upgrade to iApp Pro: <a href="http://theme-art.com/iapp/" target="_blank" class="get-pro">iApp Pro Demo</a>','iapp'),
        'section'  			=> 'iapp_more',
        'settings' 			=> 'iapp_pro',
    )));
	
	
    //  =============================================================
    //  = 					 	General Options						=
    //  =============================================================
	
    $wp_customize->add_section('iapp_general_options', array(
        'title'    			=> __('General Options', 'iapp'),
        'priority' 			=> 2,
    ));
	
    $wp_customize->add_setting('iapp_logo', array(
        'default'           => get_template_directory_uri().'/images/logo.png',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_logo', array(
        'label'    			=> __('Logo', 'iapp'),
        'section'  			=> 'iapp_general_options',
        'settings' 			=> 'iapp_logo',
    )));
	

    $wp_customize->add_setting('iapp_homebgimage', array(
        'default'           => get_template_directory_uri().'/images/homepage.jpg',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_homebgimage', array(
        'label'    			=> __('Homepage Background Image', 'iapp'),
        'section'  			=> 'iapp_general_options',
        'settings' 			=> 'iapp_homebgimage',
    )));
	

    $wp_customize->add_setting('iapp_homebgcolor', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
        'capability'        => 'edit_theme_options',
        'type'           	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'iapp_homebgcolor', array(
        'label'    			=> __('Homepage Background Color', 'iapp'),
        'section'  			=> 'iapp_general_options',
        'settings' 			=> 'iapp_homebgcolor',
    )));
	
	
    //  =============================================================
    //  = 					 	Blog Options						=
    //  =============================================================
	
    $wp_customize->add_section('iapp_blog_options', array(
        'title'    			=> __('Blog Options', 'iapp'),
        'priority' 			=> 3,
    ));
	
    $wp_customize->add_setting('iapp_blog_sidebar', array(
        'default'        	=> 'rightsidebar',
		'sanitize_callback' => 'sanitize_text_field',
        'capability'     	=> 'edit_theme_options',
        'type' 			 	=> 'theme_mod', 
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control('iapp_blog_sidebar', array(
        'label'      		=> __('Blog sidebar', 'iapp'),
        'section'    		=> 'iapp_blog_options',
        'settings'   		=> 'iapp_blog_sidebar',
		'type'				=> 'radio',
        'choices'    		=> array(
								'rightsidebar' => __('Right Sidebar', 'iapp'),
								'leftsidebar' => __('Left Sidebar', 'iapp'),
        ),
    ));
	
    $wp_customize->add_setting('iapp_blogbgimage', array(
        'default'           => get_template_directory_uri().'/images/blog.jpg',
		'sanitize_callback' => 'esc_url_raw',
        'capability'        => 'edit_theme_options',
        'type' 			 	=> 'theme_mod',
		'transport'	 		=> 'postMessage',
    ));

    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'iapp_blogbgimage', array(
        'label'    			=> __('Blog Background Image', 'iapp'),
        'section'  			=> 'iapp_blog_options',
        'settings' 			=> 'iapp_blogbgimage',
    )));
	
	
}
add_action( 'customize_register', 'iapp_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function iapp_customize_preview_js() {
	wp_enqueue_script( 'iapp_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'iapp_customize_preview_js' );

